@@ -32,6 +32,9 @@
     }
     result <- rep(NA, length(x))
     multibyte <- grepl("[^!-~ ]", x)
+    if (inherits(x, "haven_labelled")) {
+        attributes(x) <- NULL
+    }
     result[!multibyte] <- suppressWarnings(as.numeric(x[!multibyte]))
     return(result)
 }
