@@ -166,8 +166,7 @@
         }
     }
     else if (!is.matrix(expression)) {
-        cat(enter)
-        stop(simpleError(paste0("The input should be either a character expression or a matrix.", enter, enter)))
+        stopError("The input should be either a character expression or a matrix.")
     }
     if (is.null(noflevels)) noflevels <- rep(2, ncol(expression))
     expression <- dnf(remred(expression), noflevels = noflevels, partial = partial)
@@ -179,8 +178,7 @@
         return(expression)
     }
     if (is.null(colnames(expression))) {
-        cat(enter)
-        stop(simpleError(paste0("The input matrix should have column names.", enter, enter)))
+        stopError("The input matrix should have column names.")
     }
     scollapse <- scollapse | any(nchar(snames) > 1)
     expression <- writePrimeimp(expression, multivalue, collapse = ifelse(scollapse, "*", ""))
