@@ -28,7 +28,12 @@
         return(FALSE)
     }
     if (inherits(x, "haven_labelled") || inherits(x, "declared")) {
-        return(Recall(unclass(x)) && !any(is.na(suppressWarnings(as.numeric(names(attr(x, "labels")))))))
+        num <- Recall(unclass(x))
+        labels <- attr(x, "labels")
+        if (!is.null(labels) && num) {
+            return(Recall(labels))
+        }
+        return(num)
     }
     if (is.numeric(x)) {
         return(TRUE)
