@@ -47,16 +47,13 @@
         x <- unclass(x)
     }
     if (missing(x)) {
-        cat("\n")
-        stop(simpleError("Argument \"x\" is missing.\n\n"))
+        stopError("Argument \"x\" is missing.")
     }
     if (!is.atomic(x))   {
-        cat("\n")
-        stop(simpleError("The input \"x\" should be an atomic vector / factor.\n\n"))
+        stopError("The input \"x\" should be an atomic vector / factor.")
     }
     if (all(is.na(x))) {
-        cat("\n")
-        stop(simpleError("All values are missing in x.\n\n"))
+        stopError("All values are missing in x.")
     }
     dots <- recreate(list(...))
     as.factor.result  <- if (is.element("as.factor.result",  names(dots))) dots$as.factor.result  else FALSE
@@ -124,8 +121,7 @@
         newval[newval == "missing" | newval == "NA"] <- NA
         if (any(oldval == "else")) {
             if (sum(oldval == "else") > 1) {
-                cat("\n")
-                stop(simpleError("Too many \"else\" statements.\n\n"))
+                stopError("Too many \"else\" statements.")
             }
             whichelse <- which(oldval == "else")
             oldval <- c(oldval[-whichelse], oldval[whichelse])
@@ -136,8 +132,7 @@
         })
         newval <- trimstr(rep(newval, unlist(lapply(oldval, length))))
         if (any(unlist(lapply(oldval, function(y) lapply(y, length))) > 2)) {
-            cat("\n")
-            stop(simpleError("Too many : sequence operators.\n\n"))
+            stopError("Too many : sequence operators.")
         }
         from <- unlist(lapply(oldval, function(y) lapply(y, "[", 1)))
         to <- unlist(lapply(oldval, function(y) lapply(y, "[", 2)))
@@ -183,8 +178,7 @@
             cut <- asNumeric(cut)
         }
         if (any(duplicated(cut))) {
-            cat("\n")
-            stop(simpleError("Cut values should be unique.\n\n"))
+            stopError("Cut values should be unique.")
         }
         if (missing(values)) {
             values <- seq(length(cut) + 1)
@@ -201,8 +195,7 @@
                 as.numeric.result <- possibleNumeric(values)
             }
             else {
-                cat("\n")
-                stop(simpleError(paste0("There should be ", length(cut) + 1, " values for ", length(cut), " cut value", ifelse(length(cut) == 1, "", "s"), ".\n\n")))
+                stopError(paste0("There should be ", length(cut) + 1, " values for ", length(cut), " cut value", ifelse(length(cut) == 1, "", "s"), "."))
             }
         }
         if (is.factor(x)) {
@@ -235,8 +228,7 @@
             if (declared) {
                 message <- paste(message, "Consider using undeclare() before recoding.")
             }
-            cat("\n")
-            stop(simpleError(paste0(message, "\n\n")))
+            stopError(message)
         }
         if (is.factor(x)) {
             nx <- as.numeric(x)
